@@ -52,7 +52,7 @@ enum {
 	PROP_TIME_ONLY,
 };
 
-G_DEFINE_TYPE (GnomeWallClock, gnome_wall_clock, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE (GnomeWallClock, gnome_wall_clock, G_TYPE_OBJECT);
 
 static gboolean update_clock (gpointer data);
 static void on_schema_change (GSettings *schema,
@@ -70,7 +70,7 @@ gnome_wall_clock_init (GnomeWallClock *self)
 {
 	GFile *tz;
 
-	self->priv = G_TYPE_INSTANCE_GET_PRIVATE (self, GNOME_TYPE_WALL_CLOCK, GnomeWallClockPrivate);
+	self->priv = gnome_wall_clock_get_instance_private (self);
 
 	self->priv->timezone = g_time_zone_new_local ();
 
@@ -202,8 +202,6 @@ gnome_wall_clock_class_init (GnomeWallClockClass *klass)
 							       "",
 							       FALSE,
 							       G_PARAM_READABLE | G_PARAM_WRITABLE));
-
-	g_type_class_add_private (gobject_class, sizeof (GnomeWallClockPrivate));
 }
 
 /* Replace 'target' with 'replacement' in the input string. */
@@ -241,7 +239,9 @@ date_time_format (GDateTime *datetime,
 	/* Then do the same with en-space and underscore before passing it to
 	 * g_date_time_format.  */
 	no_enspace = string_replace (no_ratio, " ", "_");
+	g_debug ("no_enspace: %s", no_enspace);
 	replaced_format = g_date_time_format (datetime, no_enspace);
+	g_debug ("replaced_format: %s", replaced_format);
 
 	g_free (no_ratio);
 	g_free (no_enspace);
@@ -263,6 +263,8 @@ date_time_format (GDateTime *datetime,
 	}
 
 	g_free (replaced_format);
+	g_debug ("is_utf8: %s", is_utf8 ? "TRUE" : "FALSE");
+	g_debug ("ret: %s", ret);
 	return ret;
 }
 
@@ -314,6 +316,11 @@ gnome_wall_clock_string_for_datetime (GnomeWallClock      *self,
 {
 	const char *format_string;
 
+	g_debug ("clock_format: %s", clock_format == G_DESKTOP_CLOCK_FORMAT_24H ? "24h" : "12h");
+	g_debug ("show_weekday: %s", show_weekday ? "TRUE" : "FALSE");
+	g_debug ("show_full_date: %s", show_full_date ? "TRUE" : "FALSE");
+	g_debug ("show_seconds: %s", show_seconds ? "TRUE" : "FALSE");
+
 	if (clock_format == G_DESKTOP_CLOCK_FORMAT_24H) {
 		if (show_full_date) {
 			if (show_weekday)
@@ -366,6 +373,8 @@ gnome_wall_clock_string_for_datetime (GnomeWallClock      *self,
 		}
 	}
 
+	g_debug ("format_string: %s", format_string);
+
 	return date_time_format (now, format_string);
 }
 
